@@ -35,12 +35,12 @@
 
 #include <Lum/OS/Main.h>
 
+#include <Lum/Button.h>
 #include <Lum/Dialog.h>
 #include <Lum/Space.h>
 #include <Lum/String.h>
 #include <Lum/Table.h>
 #include <Lum/Text.h>
-#include <Lum/WindowGroup.h>
 
 #include "Package.h"
 #include "PackageDetails.h"
@@ -69,17 +69,13 @@ public:
       break;
     }
   }
-
-  Lum::OS::Color GetTextColor(size_t column, size_t row) const
-  {
-    return Lum::OS::display->GetColor(Lum::OS::Display::tableTextColor);
-  }
 };
 
 class MainDialog : public Lum::Dialog
 {
 private:
   std::list<Package>                 packages;
+  Lum::Model::ActionRef              clearFilterAction;
   Lum::Model::ActionRef              showPackageAction;
   Lum::Model::ActionRef              aboutAction;
   std::wstring                       lastSearch;
@@ -91,7 +87,8 @@ private:
 
 public:
   MainDialog()
-  : showPackageAction(new Lum::Model::Action()),
+  : clearFilterAction(new Lum::Model::Action()),
+    showPackageAction(new Lum::Model::Action()),
     aboutAction(new Lum::Model::Action()),
     search(new Lum::Model::String(L"")),
     searchTimerAction(new Lum::Model::Action()),
@@ -99,71 +96,62 @@ public:
     selection(new Lum::Model::SingleLineSelection()),
     packageListTask(packages)
   {
-    AttachModel(packageListTask.GetFinishedAction());
+    Observe(packageListTask.GetFinishedAction());
 
-    AttachModel(GetOpenedAction());
-    AttachModel(GetClosedAction());
+    Observe(GetOpenedAction());
+    Observe(GetClosedAction());
 
-    AttachModel(search);
-    AttachModel(searchTimerAction);
+    Observe(search);
+    Observe(searchTimerAction);
 
-    AttachModel(selection);
+    Observe(selection);
 
-    AttachModel(showPackageAction);
-    AttachModel(aboutAction);
+    Observe(clearFilterAction);
+    Observe(showPackageAction);
+    Observe(aboutAction);
 
     DetectOssoVersion();
   }
 
-  ~MainDialog()
-  {
-    UnattachModel(aboutAction);
-    UnattachModel(showPackageAction);
-
-    UnattachModel(selection);
-
-    UnattachModel(searchTimerAction);
-    UnattachModel(search);
-
-    UnattachModel(GetClosedAction());
-    UnattachModel(GetOpenedAction());
-
-    UnattachModel(packageListTask.GetFinishedAction());
-  }
-
   virtual void PreInit()
   {
     Lum::Button           *button;
-    Lum::Panel            *hpanel,*vpanel;
+    Lum::Panel            *vpanel,*hpanel;
     Lum::String           *string;
     Lum::Table            *table;
-    Lum::Text             *text;
-    Lum::WindowGroup      *wGroup;
     Lum::Model::HeaderRef headerModel;
 
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
-
-    hpanel=new Lum::HPanel();
-    hpanel->SetFlex(true,true);
-
     vpanel=new Lum::VPanel();
     vpanel->SetFlex(true,true);
 
+    hpanel=new Lum::HPanel();
+    hpanel->SetFlex(true,false);
+
+    hpanel->Add(new Lum::Text(L"Filter:"));
+
+    hpanel->Add(new Lum::HSpace());
+
     string=new Lum::String();
     string->SetFlex(true,false);
     string->SetModel(search);
+    hpanel->Add(string);
 
-    vpanel->Add(string);
+    button=new Lum::Button(L"_Clear");
+    button->SetFlex(false,true);
+    button->SetModel(clearFilterAction);
+    hpanel->Add(button);
+
+    vpanel->Add(hpanel);
     vpanel->Add(new Lum::VSpace());
 
     headerModel=new Lum::Model::HeaderImpl();
-    headerModel->AddColumn(L"Package",Lum::Base::Size::stdCharWidth,30,true);
-    headerModel->AddColumn(L"Version",Lum::Base::Size::stdCharWidth,10,false);
+    headerModel->AddColumn(L"Package",Lum::Base::Size::stdCharWidth,28,true);
+    headerModel->AddColumn(L"Version",Lum::Base::Size::stdCharWidth,12,false);
 
     table=new Lum::Table();
     table->SetFlex(true,true);
-    table->SetMinHeight(Lum::Base::Size::stdCharHeight,10);
+    table->SetMinHeight(Lum::Base::Size::stdCharHeight,5);
+    table->SetHeight(Lum::Base::Size::stdCharHeight,10);
     table->SetModel(currentPackages);
     table->SetHeaderModel(headerModel);
     table->SetSelection(selection);
@@ -174,30 +162,20 @@ public:
     table->GetTableView()->SetAutoHSize(true);
 
     vpanel->Add(table);
-    hpanel->Add(vpanel);
 
-    hpanel->Add(new Lum::HSpace());
+    SetMain(vpanel);
 
-    vpanel=new Lum::VPanel();
-    vpanel->SetFlex(false,true);
+    Lum::MenuDesc *menu=new Lum::MenuDesc();
 
-    text=new Lum::Text();
-    text->SetFlex(true,false);
-    text->SetText(ossoVersion,Lum::OS::Font::bold,Lum::Text::centered);
-    vpanel->Add(text);
+    menu
+      ->AddMenuItemSub(_ld(menuProject))
+        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
+    menu
+      ->AddMenuItemSub(_ld(menuHelp))
+        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
+        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
 
-    vpanel->Add(new Lum::VSpace(true));
-
-    button=new Lum::Button(L"_About");
-    button->SetFlex(true,false);
-    button->SetModel(aboutAction);
-    vpanel->Add(button);
-
-    hpanel->Add(vpanel);
-
-    wGroup->SetMain(hpanel);
-
-    SetTop(wGroup);
+    SetMenu(menu);
 
     packageListTask.SetParent(this);
     packageListTask.SetCaption(L"Reading package list...");
@@ -261,6 +239,11 @@ public:
       currentPackages->Off();
       packageListTask.Start();
     }
+    else if (model==clearFilterAction && clearFilterAction->IsFinished()) {
+      lastSearch==L"";
+      search->Set(L"");
+      UpdateEntries();
+    }
     else if (model==showPackageAction && showPackageAction->IsFinished()) {
       Package*       package=dynamic_cast<PackageEntry*>(currentPackages->GetEntry(selection->GetLine()))->GetPackage();
       PackageDetails *dialog;
