@@ -22,38 +22,40 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
-#include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Edit/Edit.h>
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
 #include <Lum/Tab.h>
+#include <Lum/Text.h>
 #include <Lum/View.h>
-#include <Lum/WindowGroup.h>
 
 PackageDetails::PackageDetails(Package& package)
  : package(package)
 {
-  AttachModel(GetClosedAction());
+  Observe(GetClosedAction());
 }
 
-PackageDetails::~PackageDetails()
+Lum::Object* PackageDetails::GetTextField(const std::wstring& text) const
 {
-  UnattachModel(GetClosedAction());
+  Lum::Text *t;
+
+  t=new Lum::Text(text);
+  t->SetFlex(true,false);
+  t->SetMaxWidth(Lum::Base::Size::stdCharWidth,20);
+
+  return t;
 }
 
 void PackageDetails::PreInit()
 {
-  Lum::Button           *button;
-  Lum::ButtonRow        *row;
-  Lum::Edit::Edit       *edit;
-  Lum::Edit::Text       *editContent;
-  Lum::Label            *label;
-  Lum::Panel            *vPanel;
-  Lum::Tab              *tab;
-  Lum::View             *view;
-  Lum::WindowGroup      *wGroup;
+  Lum::ButtonRow  *row;
+  Lum::Edit::Edit *edit;
+  Lum::Edit::Text *editContent;
+  Lum::Panel      *vPanel;
+  Lum::Tab        *tab;
+  Lum::View       *view;
 
   vPanel=new Lum::VPanel();
   vPanel->SetFlex(true,true);
@@ -61,17 +63,30 @@ void PackageDetails::PreInit()
   tab=new Lum::Tab();
   tab->SetFlex(true,true);
 
-  label=new Lum::Label();
-  label->SetFlex(true,true);
-
-  label->AddLabel(L"Package:",package.GetName()+L" "+package.GetVersion()+ L" ("+package.GetSection()+L")");
-  label->AddLabel(L"Description:",package.GetShortDescription().empty() ? L"<no description>" : package.GetShortDescription());
-  label->AddLabel(L"Maintainer:",package.GetMaintainer().empty() ? L"<no maintainer>" : package.GetMaintainer());
-  label->AddLabel(L"Homepage:", package.GetHomepage().empty() ? L"<no homepage> " : package.GetHomepage());
-  label->AddLabel(L"Size (deb/inst.):",Lum::Base::NumberToWString(package.GetPackageSize())+L"/"+
+  editContent=new Lum::Edit::Text();
+  editContent->SetText(L"Package: "+package.GetName()+L" "+package.GetVersion()+ L" ("+package.GetSection()+L")\n"+
+                       L"Description: "+(package.GetShortDescription().empty() ? L"<no description>" : package.GetShortDescription())+L"\n"+
+                       L"Maintainer: "+(package.GetMaintainer().empty() ? L"<no maintainer>" : package.GetMaintainer())+L"\n"+
+                       L"Homepage: "+(package.GetHomepage().empty() ? L"<no homepage> " : package.GetHomepage())+L"\n"+
+                       L"Size (deb/inst.): "+Lum::Base::NumberToWString(package.GetPackageSize())+L"/"+
                   Lum::Base::NumberToWString(package.GetInstalledSize()));
+  editContent->Disable();
 
-  tab->Add(L"Data",label);
+  view=new Lum::View();
+  view->SetFlex(true,true);
+
+  edit=new Lum::Edit::Edit();
+  edit->SetFlex(true,true);
+  edit->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
+  edit->SetMinHeight(Lum::Base::Size::stdCharHeight,5);
+  edit->SetConfig(Lum::Edit::Config::GetDefaultConfig());
+  edit->SetColorSheme(Lum::Edit::ColorSheme::GetDefaultColorSheme());
+  edit->SetFont(Lum::OS::display->GetFont());
+  edit->SetModel(editContent);
+
+  view->SetObject(edit);
+
+  tab->Add(L"Data",view);
 
   editContent=new Lum::Edit::Text();
   editContent->SetText(package.GetDescription());
@@ -82,7 +97,7 @@ void PackageDetails::PreInit()
 
   edit=new Lum::Edit::Edit();
   edit->SetFlex(true,true);
-  edit->SetMinWidth(Lum::Base::Size::stdCharWidth,55);
+  edit->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
   edit->SetMinHeight(Lum::Base::Size::stdCharHeight,5);
   edit->SetConfig(Lum::Edit::Config::GetDefaultConfig());
   edit->SetColorSheme(Lum::Edit::ColorSheme::GetDefaultColorSheme());
@@ -102,7 +117,7 @@ void PackageDetails::PreInit()
 
   edit=new Lum::Edit::Edit();
   edit->SetFlex(true,true);
-  edit->SetMinWidth(Lum::Base::Size::stdCharWidth,55);
+  edit->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
   edit->SetMinHeight(Lum::Base::Size::stdCharHeight,5);
   edit->SetConfig(Lum::Edit::Config::GetDefaultConfig());
   edit->SetColorSheme(Lum::Edit::ColorSheme::GetDefaultColorSheme());
@@ -117,23 +132,11 @@ void PackageDetails::PreInit()
 
   vPanel->Add(new Lum::VSpace());
 
-  row=new Lum::ButtonRow();
+  row=Lum::ButtonRow::CreateClose(GetClosedAction());
   row->SetFlex(true,false);
-
-  button=new Lum::Button;
-  button->SetFlex(true,true);
-  button->SetModel(GetClosedAction());
-  button->SetText(_ld(dlgButtonOk));
-  button->SetType(Lum::Button::typeCommit);
-  row->Add(button);
-
   vPanel->Add(row);
 
-  wGroup=new Lum::WindowGroup();
-  wGroup->SetFlex(true,true);
-  wGroup->SetMain(vPanel);
-
-  SetTop(wGroup);
+  SetMain(vPanel);
 
   Lum::Dialog::PreInit();
 }
