@@ -29,9 +29,11 @@ class PackageDetails : public Lum::Dialog
 private:
   Package& package;
 
+private:
+  Lum::Object* GetTextField(const std::wstring& text) const;
+
 public:
   PackageDetails(Package& package);
-  ~PackageDetails();
 
   void PreInit();
 
